PrinterImpl class

Implemented types
Annotations
  • @sealed

Constructors

PrinterImpl.frbInternalDcoDecode(List wire)
PrinterImpl.frbInternalSseDecode(BigInt ptr, int externalSizeOnNative)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether the underlying Arc is disposed.
no setterinherited
move ← bool?
no getterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose the underlying Arc.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited